****************************************
aioesl: Protocol for Freeswitch Event Socket
****************************************

About
=====
aioesl support inbound and outbound connections.

For more information read https://freeswitch.org/confluence/display/FREESWITCH/mod_event_socket

Requirements
=============

* Python 3.5.1


Examples
=========

Examples are available in the examples/ directory.

